/**
 *  @file data.c
 *
 *  @author Collin R. Mulliner <collin@mulliner.org>
 *
 *  This is part of the Bluetooth Location Tracker (BLT) project
 */

#include "bltwebd.h"

int blt_parseDataLine(char *buffer, struct blt_device_status_t *nDev)
{
	char *p;
	struct tm tmp_time;
	

	memset(nDev, 0, sizeof(struct blt_device_status_t));

	parsemac(buffer, nDev->dev.bdAddr);
	p = strstr(buffer, "\"");
	if (p > 0) p = scanWithEsc(p+1, nDev->dev.name, BLT_DEVICE_NAME_LENGTH+1);
	else return(0);
	p = strstr(p, "0x");
	if (p > 0) nDev->dev.devClass = strtoul(p, NULL, 16);
	else return(0);
	p += 2;
	p = strstr(p, "0x");
	if (p > 0) nDev->rssi = strtoul(p, NULL, 16);
	else return(0);
	p = strstr(p, "\"");
	memset(&tmp_time, 0, sizeof(struct tm));
	sscanf(p, "\"%d.%d.%d %d:%d:%d\", %d, %d)", &tmp_time.tm_mon,
		&tmp_time.tm_mday,	&tmp_time.tm_year, &tmp_time.tm_hour, &tmp_time.tm_min,
		&tmp_time.tm_sec, &nDev->la, &nDev->lg);
		
	tmp_time.tm_year -= 1900;
	tmp_time.tm_mon--;
	nDev->tStamp = mktime(&tmp_time);
	
	return(1);
}

int blt_dumpAll(struct blt_dev_names_t *dev, struct blt_loc_names_t *locs, char *outfile, unsigned int age)
{
	const unsigned char EMPTY_MAC[6] = { 0x00,0x00,0x00,0x00,0x00,0x00 };
	FILE *fp;
	int i, i2, i3;
	struct blt_location_name_t curLoc;
	struct blt_device_status_t *cd;
	char bt_class[1024];
	char buffer[1024];
	time_t curTime;
	
	
	curTime = time(NULL);

	memset(&curLoc, 0, sizeof(struct blt_location_name_t));
	
	if ((fp = fopen(outfile, "w")) == NULL) {
		printf("error can't write file: %s\n", outfile);
		return(0);
	}
	
	fprintf(fp, "<!-- AUTO GENERATED - DO NOT EDIT //-->\n<?php\n\n$blt_location_data = array(\n");
	
	i = 0; i2 = 0;
	while (i < DN_HASHTABLE_SIZE && i2 < dev->numDevices) {
		if (memcmp(&dev->devices[i].dev.bdAddr, EMPTY_MAC, 6) == 0) {
			i++;
			continue;
		}
		cd = &dev->devices[i];

		if (cd->tStamp+age < curTime) {
			i++;
			i2++;
			continue;
		}
		
		/* get location name */
		if (cd->la != curLoc.la || cd->lg != curLoc.lg) {
			memset(&curLoc, 0, sizeof(struct blt_location_name_t));
			i3 = 0;
			while (i3 < locs->numLocations) {
				if (locs->locs[i3].la == cd->la && locs->locs[i3].lg == cd->lg) {
					memcpy(&curLoc, &locs->locs[i3], sizeof(struct blt_location_name_t));
					break;
				}
				i3++;
			}
		}

		memset(bt_class, 0, 1024);		
		bluetooth_classToString(cd->dev.devClass, " ", NULL, bt_class, NULL);
		strcat(bt_class, " ");
		bluetooth_classToString(cd->dev.devClass, " ", NULL, NULL, bt_class+strlen(bt_class));
		memset(buffer, 0, 1024);
		printWithEsc(cd->dev.name, buffer, 1024);
		
		fprintf(fp, "array(\"sel\"=>0, \"bdaddr\"=>\"%.2X:%.2X:%.2X:%.2X:%.2X:%.2X\", \"name\"=>\"%s\", \"class\"=>\"%s\", \"rssi\"=>\"0x%.2X\", \"location\"=>\"%s\", \"time\"=>\"%d\"),\n",
			cd->dev.bdAddr[0],cd->dev.bdAddr[1],cd->dev.bdAddr[2],cd->dev.bdAddr[3],cd->dev.bdAddr[4],cd->dev.bdAddr[5],
			buffer, bt_class, cd->rssi, curLoc.name, (unsigned int)cd->tStamp);

		i++; i2++;
	}
	fprintf(fp, ");\n\n?>\n");
	
	fclose(fp);
	
	return(1);
}
